==> kpopup-0.3.1.tar.gz: kpopup-0.3.1/kpopup/kpopup.h <==
/***************************************************************************
                          kpopup.h  -  description
                          ------------------------
    copyright            : (C) 2000 by Torsten Henschel
    email                : henschel@fh-brandenburg.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include <kapp.h>

#include <qdatetime.h>
#include <qlabel.h>
#include <qpushbutton.h>
#include <qwidget.h>


class KPopup : public QWidget
{
 Q_OBJECT

 public:
        KPopup(int argc, char **argv, QWidget *parent = 0, const char *name = 0);
        KPopup();

 public slots:
              void AnswerPopup();
              void NewPopup();
    
 private:
         KConfig *config;
         QPushButton *B_Quit;
         QPushButton *B_Answer_Popup;
         QPushButton *B_New_Popup;
         QLabel *L_PopupText;
         QLabel *L_Label_Sender;
         QLabel *L_Sender;
         QLabel *L_Label_DateTime;
         QLabel *L_DateTime;
         QDate *Date;
         QTime *Time;
         char *Sender;
         char *Filename;
};

==> kpopup-0.5.0.tar.gz: kpopup-0.5.0/kpopup/kpopup.h <==
/***************************************************************************
                          kpopup.h  -  description
                          ------------------------
    copyright            : (C) 2000 by Torsten Henschel
    email                : henschel@fh-brandenburg.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef KOPUP_H
#define KOPUP_H

#include <kapp.h>
#include <ktmainwindow.h>
#include <kiconloader.h>

#include <qdatetime.h>
#include <qlabel.h>
#include <qpushbutton.h>

#include "resource.h"

class Kpopup : public KTMainWindow
{
 Q_OBJECT

 public:
         Kpopup(int argc, char **argv, QWidget* parent=0, const char *name=0);
        ~Kpopup();
         void AnswerPopup();
         void NewPopup();
         void SetStatusText(const char *);

 private slots:
               void commandCallback(int);
               void timerDone();

 private:
         void Init();
         void InitToolbar();
         void InitStatusbar();

         KIconLoader *loader;
         KMenuBar *menu;
         KStatusBar *statusbar;
         KToolBar *toolbar;
         QPopupMenu *file;
         QPopupMenu *help;
         QLabel *L_PopupText;
         QLabel *L_Label_Sender;
         QLabel *L_Sender;
         QLabel *L_Label_DateTime;
         QLabel *L_DateTime;
         QDate *Date;
         QTime *Time;
         QTimer *timer;
         char *Sender;
         char *Filename;
};

#endif
